// Copyright 2006 Omni Development, Inc.  All rights reserved.
//
// This software may only be used and reproduced according to the
// terms in the file OmniSourceLicense.html, which should be
// distributed with this project and can also be found at
// <http://www.omnigroup.com/developer/sourcecode/sourcelicense/>.
//
// $Header: svn+ssh://source.omnigroup.com/Source/svn/Omni/tags/OmniSourceRelease_2006-09-07/OmniGroup/Frameworks/OmniInspector/OIInspector.h 79095 2006-09-08 00:19:03Z kc $

#import <AppKit/NSResponder.h>

@class NSBundle, NSDictionary, NSPredicate; // Foundation
@class NSImage, NSMenuItem, NSView; // AppKit

@interface OIInspector : NSResponder
{
@private
    NSString *_identifier;
    NSString *_displayName;
    BOOL _defaultVisibility;
    NSString *_shortcutKey;
    unsigned int _shortcutModifierFlags;
    NSBundle *resourceBundle;
    NSString *_imageName, *tabImageName;
    NSImage  *_image;
    unsigned int _defaultOrderingWithinGroup;
}

+ createInspectorWithDictionary:(NSDictionary *)dict;
- initWithDictionary:(NSDictionary *)dict;

- (NSString *)identifier;
- (BOOL)defaultVisibility;
- (NSString *)shortcutKey;
- (unsigned int)shortcutModifierFlags;
- (NSImage *)image;
- (NSImage *)tabImage;
- (NSBundle *)resourceBundle;

- (NSString *)displayName;

- (unsigned int)defaultOrderingWithinGroup;
- (void)setDefaultOrderingWithinGroup:(unsigned int)defaultOrderingWithinGroup;

// TODO: Get rid of this
- (unsigned int)deprecatedDefaultDisplayGroupNumber;

- (NSMenuItem *)menuItemForTarget:(id)target action:(SEL)action;
- (NSArray *)menuItemsForTarget:(id)target action:(SEL)action;

- (void)setControlsEnabled:(BOOL)enabled;
- (void)setControlsEnabled:(BOOL)enabled inView:(NSView *)view;

@end

@protocol OIConcreteInspector
- (NSView *)inspectorView;
    // Returns the view which will be placed into a grouped Info window

#if defined(MAC_OS_X_VERSION_10_4) && MAC_OS_X_VERSION_MIN_REQUIRED >= MAC_OS_X_VERSION_10_4
- (NSPredicate *)inspectedObjectsPredicate;
    // Return a predicate to filter the inspected objects down to what this inspector wants sent to its -inspectObjects: method
#else
- (Class)inspectsClass;
    // Return the class of objects that this inspector expects to receive in its -inspectObjects: method
#endif

- (void)inspectObjects:(NSArray *)objects;
    // This method is called whenever the selection changes
@end

@interface NSObject (OITabbedInspectorOptional)
// Tabbed inspectors receive an -inspectObjects: with nil when they are hidden.  If the inspector wants its tab dimmed when there is a non-empty array that *would* be inspected if it were visible, then this method allows it to do that.  The default is for tabs to be dimmed when there are zero objects they could inspect, if visible.
- (BOOL)shouldBeDimmedForObjects:(NSArray *)objects;
- (BOOL)shouldBeDimmed;
@end

// This is not implemented; this just allows you to call the concrete methods.  -[OIInspector initWithDictionary:] asserts that the class conforms.
@interface OIInspector (OIConcreteInspector) <OIConcreteInspector>
@end

@class OIInspectorController;
@interface NSObject (OIInspectorOptionalMethods)
- (void)setInspectorController:(OIInspectorController *)aController;
    // If the inspector has any need to know its controller, it can implement this method
- (float)inspectorWillResizeToHeight:(float)height;
- (float)inspectorMinimumHeight;
- (id)windowTitle; 
    // If implemented, this will be used instead of -inspectorName, to let the window title be dynamic. NSAttributedString or NSString are ok.

- (NSDictionary *)configuration;
- (void)loadConfiguration:(NSDictionary *)dict;
    // These methods will be called to save and load any configuration information for the inspectors themselves on startup/shutdown and when workspaces are switched

- (BOOL)mayInspectObject:anObject;

@end

